@@ -90,16 +90,7 @@
 #' generate the vector of individual probabilities. This is done using 
 #' \code{\link{expectOrderBeta}} and requires the user to set a seed to 
 #' reproduce results. 
-#'  
-#' Informative two-stage hierarchical (Dorfman) testing is implemented via 
-#' the pool-specific optimal Dorfman (PSOD) method described in McMahan et al. 
-#' (2012a), where the greedy algorithm proposed for PSOD is replaced by 
-#' considering all possible testing configurations. Informative array testing 
-#' is implemented via the gradient method (the most efficient array design), 
-#' where higher-risk individuals are grouped in the left-most columns of the 
-#' array. For additional details on the gradient arrangement method for 
-#' informative array testing, see McMahan et al. (2012b).
-#' 
+#'
 #' The sensitivity/specificity values are allowed to vary across stages of 
 #' testing. For hierarchical testing, a different sensitivity/specificity value 
 #' may be used for each stage of testing. For array testing, a different 
@@ -231,9 +222,7 @@
 #' config.mat <- matrix(data = c(rep(1, 10), 1:10), 
 #'                      nrow = 2, ncol = 10, byrow = TRUE)
 #' opChar1(algorithm = "D2", p = 0.05, Se = 0.99, Sp = 0.99, 
-#'         hier.config = config.mat)
-#' opChar1(algorithm = "D2", p = 0.05, Se = 0.99, Sp = 0.99, 
-#'         hier.config = config.mat, a = c(1,4), print.time = FALSE)
+#'         hier.config = config.mat, print.time = FALSE)
 #'
 #' # Calculate the operating characteristics for informative
 #' #   two-stage hierarchical (Dorfman) testing.
@@ -646,347 +635,3 @@ opChar1 <- operatingCharacteristics1
 
 
 
-
-# Summary function for operatingCharacteristics1() and 
-#   operatingCharacteristics2()
-###############################################################################
-
-#' @title Summary method for operating characteristics results
-#' 
-#' @description Produce a summary list for objects of class 
-#' \kbd{"opChar"} returned by \code{\link{operatingCharacteristics1}} 
-#' (\kbd{opChar1}) or \code{\link{operatingCharacteristics2}} 
-#' (\kbd{opChar2}).
-#' 
-#' @param object an object of class \kbd{"opChar"}, providing the calculated 
-#' operating characteristics for a group testing algorithm.
-#' @param ... currently not used.
-#' 
-#' @details This function produces a summary list for objects of 
-#' class \kbd{"opChar"} returned by \code{\link{operatingCharacteristics1}} 
-#' (\kbd{opChar1}) or \code{\link{operatingCharacteristics2}} 
-#' (\kbd{opChar2}). It formats the testing configuration, expected number 
-#' of tests, expected number of tests per individual, and accuracy measures. 
-#' 
-#' The \kbd{Configuration} component of the result
-#' gives the testing configuration, which may include the group sizes for 
-#' each stage of a hierarchical testing algorithm or the row/column size and
-#' array size for an array testing algorithm. The \kbd{Tests} component 
-#' of the result gives the expected number of tests and the expected 
-#' number of tests per individual for the algorithm. 
-#' 
-#' The \kbd{Accuracy} component gives the individual accuracy measures for 
-#' each individual in \kbd{object} and the overall accuracy measures for the 
-#' algorithm. Accuracy measures included are the pooling sensitivity, pooling 
-#' specificity, pooling positive predictive value, and pooling negative 
-#' predictive value. The overall accuracy measures displayed are weighted 
-#' averages of the corresponding individual accuracy measures for all 
-#' individuals in the algorithm. Expressions for these averages are provided 
-#' in the Supplementary Material for Hitt et al. (2019). For more information, 
-#' see the Details' section for the \code{\link{operatingCharacteristics1}} 
-#' (\kbd{opChar1}) or \code{\link{operatingCharacteristics2}} (\kbd{opChar2}) 
-#' function.
-#' 
-#' @return \kbd{summary.opChar} returns an object of class 
-#' \kbd{"summary.opChar"}, a list containing:
-#' \item{Algorithm}{character string specifying the name of the group testing 
-#' algorithm.}
-#' \item{Configuration}{matrix detailing the configuration from \kbd{object}. 
-#' For hierarchical testing, this includes the group sizes for each stage of 
-#' testing. For array testing, this includes the array dimension (row/column 
-#' size) and the array size (the total number of individuals in the array).}
-#' \item{Tests}{matrix detailing the expected number of tests and expected 
-#' number of tests per individual from \kbd{object}}.
-#' \item{Accuracy}{a list containing:
-#' \describe{
-#' \item{Individual}{matrix detailing the accuracy measures for each 
-#' individual from \kbd{object} (for objects returned by \code{\link{opChar1}}).}
-#' \item{Disease 1 Individual}{matrix detailing the accuracy measures 
-#' pertaining to disease 1 for each individual from \kbd{object} 
-#' (for objects returned by \code{\link{opChar2}}).}
-#' \item{Disease 2 Individual}{matrix detailing the accuracy measures 
-#' pertaining to disease 2 for each individual from \kbd{object}
-#' (for objects returned by \code{\link{opChar2}}).}
-#' \item{Overall}{matrix detailing the overall accuracy measures for 
-#' the algorithm from \kbd{object}.}}}
-#' 
-#' @author Brianna D. Hitt
-#' 
-#' @seealso
-#' \code{\link{operatingCharacteristics1}} (\kbd{opChar1}) and 
-#' \code{\link{operatingCharacteristics2}} (\kbd{opChar2}) for creating 
-#' an object of class \kbd{"opChar"}.
-#' 
-#' @examples 
-#' # Calculate the operating characteristics for 
-#' #   non-informative four-stage hierarchical testing.
-#' config.mat <- matrix(data = c(rep(1, 24), rep(1, 16), rep(2, 8), 
-#'                             rep(1, 8), rep(2, 8), rep(3, 4), 
-#'                             rep(4, 2), rep(5, 2), 1:24), 
-#'                      nrow = 4, ncol = 24, byrow = TRUE)
-#' calc1 <- opChar1(algorithm = "D4", p = 0.01, Se = 0.99, Sp = 0.99, 
-#'                  hier.config = config.mat, a = c(1, 9, 17, 21, 23))
-#' summary(calc1)
-#' 
-#' # Calculate the operating characteristics for 
-#' #   informative array testing without master pooling.
-#' calc2 <- opChar1(algorithm = "IA2", p = 0.025, alpha = 0.5, 
-#'                  Se = 0.95, Sp = 0.99, rowcol.sz = 12)
-#' summary(calc2)
-#' 
-#' # Calculate the operating characteristics for 
-#' #   informative two-stage hierarchical testing.
-#' config.mat <- matrix(data = c(rep(1, 5), rep(2, 4), 1, 1:10), 
-#'                      nrow = 2, ncol = 10, byrow = TRUE)
-#' Se <- matrix(data = c(rep(0.95, 2), rep(0.99, 2)), 
-#'              nrow = 2, ncol = 2, byrow = FALSE)
-#' Sp <- matrix(data = c(rep(0.96, 2), rep(0.98, 2)), 
-#'              nrow = 2, ncol = 2, byrow = FALSE)
-#' calc3 <- opChar2(algorithm = "ID2", alpha = c(18.25, 0.75, 0.75, 0.25), 
-#'                  Se = Se, Sp = Sp, hier.config = config.mat)
-#' summary(calc3)
-#' 
-#' # Calculate the operating characteristics for 
-#' #   non-informative array testing with master pooling.
-#' calc4 <- opChar2(algorithm = "A2M", p.vec = c(0.92, 0.05, 0.02, 0.01), 
-#'                  Se = rep(0.95, 2), Sp = rep(0.99, 2), rowcol.sz = 8)
-#' summary(calc4)
-
-summary.opChar <- function(object, ...) {
-  
-  # algorithm
-  algorithm <- object$algorithm
-  cat("\nAlgorithm:", algorithm, "\n\n")
-  
-  # configuration
-  config <- object$Config
-  # create a data frame detailing the configuration
-  stage1 <- config[[1]]
-  stage2 <- NULL
-  stage3 <- NULL
-  stage4 <- NULL
-  if (length(config) > 1) {
-    # three-stage and informative two-stage hierarchical testing
-    if (length(config[[2]]) > 1) {
-      stage2 <- config[[2]][1]
-      for (i in 2:length(config[[2]])) {
-        stage2 <- paste(stage2, config[[2]][i], sep = ",")
-      }
-    } else{
-      # array testing and non-informative two-stage hierarchical testing
-      stage2 <- config[[2]]
-    }
-  }
-  # four-stage hierarchical testing
-  if (length(config) > 2) {
-    if (length(config[[3]]) > 1) {
-      stage3 <- config[[3]][1]
-      for (i in 2:length(config[[3]])) {
-        stage3 <- paste(stage3, config[[3]][i], sep = ",")
-      }
-    } else{
-      stage3 <- config[[3]]
-    }
-  }
-  # five-stage hierarchical testing
-  if (length(config) > 3) {
-    if (length(config[[4]]) > 1) {
-      stage4 <- config[[4]][1]
-      for (i in 2:length(config[[4]])) {
-        stage4 <- paste(stage4, config[[4]][i], sep = ",")
-      }
-    } else{
-      stage4 <- config[[4]]
-    }
-  }
-  config <- rbind(stage1, stage2, stage3, stage4)
-  if (grepl("Informative two-stage", algorithm)) {
-    dimnames(config) <- list(c("Block size", "Group sizes"), "")
-  } else if (grepl("hierarchical", algorithm)) {
-    dimnames(config) <- list(c("Stage 1", "Stage 2", "Stage 3", 
-                               "Stage 4")[1:length(config)], "")
-  } else if (grepl("array", algorithm)) {
-    dimnames(config) <- list(c("Row/column size", "Array size"), "")
-  }
-  
-  cat("Testing configuration:\n")
-  for (i in 1:length(config)) {
-    cat(paste0(rownames(config)[i], ": ", config[i], "\n"))
-  }
-  
-  ET <- format(round(object$ET, 2), nsmall = 2)
-  value <- format(round(object$value, 4), nsmall = 4)
-  # create a matrix detailing the expected number of tests
-  tests <- matrix(data = c(ET, value), nrow = 2, ncol = 1)
-  rownames(tests) <- c("Expected number of tests", 
-                       "Expected number of tests per individual")
-  cat("\nExpected number of tests:", ET)
-  cat("\nExpected number of tests per individual:", value)
-  
-  # create a matrix for accuracy measures
-  if (class(object$Accuracy) == "matrix") {
-    ind.acc <- NULL
-    overall.acc <- as.data.frame(format(round(object$Accuracy, 4), 
-                                        nsmall = 4))
-  } else if (length(object$Accuracy) == 2) {
-    ind.acc <- object$Accuracy$Individual
-    ind.acc[, 1:4] <- format(round(ind.acc[, 1:4], 4), nsmall = 4)
-    colnames(ind.acc) <- c("PSe", "PSp", "PPPV", "PNPV", "Individuals")
-    
-    cat("\n\nAccuracy for individuals:\n")
-    print(as.data.frame(ind.acc))
-    
-    overall.acc <- as.data.frame(format(round(object$Accuracy$Overall, 4), 
-                                        nsmall = 4))
-  } else if (length(object$Accuracy) > 2) {
-    ind.acc.dis1 <- object$Accuracy$'Disease 1 Individual'
-    ind.acc.dis1[, 1:4] <- format(round(ind.acc.dis1[, 1:4], 4), nsmall = 4)
-    colnames(ind.acc.dis1) <- c("PSe", "PSp", "PPPV", "PNPV", "Individuals")
-    
-    ind.acc.dis2 <- object$Accuracy$'Disease 2 Individual'
-    ind.acc.dis2[, 1:4] <- format(round(ind.acc.dis2[, 1:4], 4), nsmall = 4)
-    colnames(ind.acc.dis2) <- c("PSe", "PSp", "PPPV", "PNPV", "Individuals")
-    
-    cat("\n\nDisease 1 accuracy for individuals:\n")
-    print(as.data.frame(ind.acc.dis1))
-    cat("\nDisease 2 accuracy for individuals:\n")
-    print(as.data.frame(ind.acc.dis2))
-    
-    overall.acc <- as.data.frame(format(round(object$Accuracy$Overall, 4), 
-                                        nsmall = 4))
-  }
-  colnames(overall.acc) <- c("PSe", "PSp", "PPPV", "PNPV")
-  
-  cat("\nOverall accuracy of the algorithm:\n")
-  print(as.data.frame(overall.acc))
-  
-  cat("\nPSe denotes the pooling sensitivity.\n")
-  cat("PSp denotes the pooling specificity.\n")
-  cat("PPPV denotes the pooling positive predictive value.\n")
-  cat("PNPV denotes the pooling negative predictive value.\n")
-  
-  if (class(object$Accuracy) == "matrix" | 
-      length(object$Accuracy) == 2) {
-    res <- list("Algorithm" = algorithm, 
-                "Configuration" = config, 
-                "Tests" = tests, 
-                "Accuracy" = list("Individual" = ind.acc, 
-                                  "Overall" = overall.acc))
-  } else {
-    res <- list("Algorithm" = algorithm, 
-                "Configuration" = config, 
-                "Tests" = tests, 
-                "Accuracy" = list("Disease 1 Individual" = ind.acc.dis1,
-                                  "Disease 2 Individual" = ind.acc.dis2,
-                                  "Overall" = overall.acc))
-  }
-  
-  class(res) <- "summary.opChar"
-  invisible(res)
-}
-
-
-
-
-# Start supporting functions for operating characteristics functions
-########################################################################
-# This function converts a numeric vector to a character string, 
-#   where values are separated by commas with no spaces
-# This function is to be used when converting a vector of individual
-#   indices or group sizes in a group testing algorithm to a character 
-#   string to be displayed in a single column in a matrix/data frame
-
-vec2string <- function(vec) {
-  res.string <- vec[1]
-  if (length(vec) > 1) {
-    for (i in 2:length(vec)) {
-      res.string <- paste(res.string, vec[i], sep = ",")
-    }
-  }
-  res.string
-}
-
-
-
-
-# This function takes a matrix of individual accuracy measures, 
-#   and finds the indices for each unique row of results
-# The output is a matrix of the unique individual accuracy measures
-#   with an additional column specifying the indices for all individuals
-#   with the same accuracy measure values
-
-get.unique.index <- function(results, col.num, rowlabel = NULL) {
-  
-  if (is.null(dim(results))) {
-    results <- matrix(data = results, nrow = 1, ncol = length(results), 
-                      dimnames = list(rowlabel, names(results)))
-  }
-  
-  results <- as.data.frame(results)
-  rows <- rownames(results)
-  
-  # account for individuals with same results as the first row
-  if (nrow(results) == 1) {
-    index <- rows
-  } else {
-    index <- rows[which(results[,col.num] == results[1,col.num])]
-  }
-  
-  index.string <- vec2string(index)
-  
-  new <- cbind(results[index[1],], as.character(index.string))
-  included <- as.character(index)
-  
-  # keep going, until all individuals are accounted for
-  while (length(included) < nrow(results)) {
-    new.start <- as.character(min(as.numeric(suppressWarnings(rows[rows != included]))))
-    index <- rows[which(results[,col.num] == results[new.start,col.num])]
-    index.string <- vec2string(index)
-    new <- rbind(new, cbind(results[index[1],], as.character(index.string)))
-    included <- as.character(sort(as.numeric(c(included, index))))
-  }
-  
-  colnames(new)[length(colnames(new))] <- c("individuals")
-  rownames(new) <- NULL
-  new
-}
-
-
-
-
-# Brianna Hitt - 03.03.2020
-#   Check whether all individual have equal accuracy measures
-#   If not, list all the indices for each unique row
-#   If yes, the individuals column will read "All"
-
-check.all.equal <- function(results, col.num) {
-  
-  results <- as.data.frame(results)
-  rows <- rownames(results)
-  
-  # account for individuals with same results as the first row
-  index <- rows[which(results[,col.num] == results[1,col.num])]
-  
-  if (length(index) == nrow(results)) {
-    index.string <- "All"
-    new <- cbind(results[1,], as.character(index.string))
-    colnames(new)[length(colnames(new))] <- c("individuals")
-    rownames(new) <- NULL
-    new
-  }
-}
-
-
-
-
-# This function creates a vector of group sizes from a group membership matrix
-get.pools <- function(group.nums){
-  pools.table <- table(group.nums)
-  pool.szs <- pools.table[[1]]
-  for (i in 2:dim(pools.table)) {
-    pool.szs <- c(pool.szs, pools.table[[i]])
-  }
-  pool.szs
-}
-
-#
\ No newline at end of file
